<p align="center">
  <a href="https://picocss.com/">
    <img src="https://picocss.com/img/logo.svg" width="64" height="64">
  </a>
</p>

<h3 align="center">Pico.css</h3>

<p align="center">
  <strong>Graceful & Minimal CSS design system in pure semantic HTML.</strong><br>
  Elegant styles for all natives HTML elements without <code>.classes</code> and dark mode automatically enabled.<br><br>
  <a href="https://picocss.com/#examples">Examples</a> ·
  <a href="https://picocss.com/docs/">Documentation</a>
</p>

# Pico.css

`5.6 KB` minified and gzipped

- **Class-light and semantic**: we use simple native HTML tags as much as possible. Only 6 .classes are used in Pico.
- **Great styles with just one CSS file**: No dependencies, package manager, external files or JavaScript.
- **Responsive everything**: Elegant and consistent adaptatives spacings and typography on all devices.
- **Light or Dark mode**: Shipped with two beautiful color themes, automatically enabled according to the user preference.

## Usage

There are 3 ways to get started with pico.css:

### Install manually
[Download Pico](https://github.com/picocss/pico/archive/v1.0.5.zip) and link `/css/pico.min.css` in the `<head>` of your website.

```html
<link rel="stylesheet" href="css/pico.min.css">
```

### Install from CDN
Alternatively, you can use the [unpkg CDN](https://unpkg.com/@picocss/pico@latest/) to link pico.css.

```html
<link rel="stylesheet" href="https://unpkg.com/@picocss/pico@latest/css/pico.min.css">
```

### Install with NPM
```shell
npm install @picocss/pico
```

## Examples

<a href="https://picocss.com/#examples">
  <img src="https://picocss.com/img/examples.jpg">
</a>

- [**Class-less**](https://picocss.com/examples/classless/): Just a pure semantic HTML markup, without `.classes`
- [**Company**](https://picocss.com/examples/company/): A classic company or blog layout with a sidebar.
- [**Google Amp**](https://picocss.com/examples/google-amp/): A simple layout for Google Amp, with inlined CSS.
- [**Sign in**](https://picocss.com/examples/sign-in/): A minimalist layout for Login pages.

## Documentation

**Getting started**
- [Usage](https://picocss.com/docs/#start)
- [Themes](https://picocss.com/docs/#themes)
- [Customization](https://picocss.com/docs/#customization)
- [Class-less version](https://picocss.com/docs/#classless)

**Layout**
- [Containers](https://picocss.com/docs/#containers)
- [Grids](https://picocss.com/docs/#grids)
- [Horizontal scroller](https://picocss.com/docs/#scroller)

**Elements**
- [Typography](https://picocss.com/docs/#typography)
- [Buttons](https://picocss.com/docs/#buttons)
- [Forms](https://picocss.com/docs/#forms)

**Components**
- [Accordions](https://picocss.com/docs/#accordions)
- [Cards](https://picocss.com/docs/#cards)
- [Navs](https://picocss.com/docs/#navs)
- [Tooltips](https://picocss.com/docs/#tooltips)

## Copyright and license

- Licensed under the [MIT License](https://github.com/picocss/pico/blob/master/LICENSE.md)
- Openly inspired by [Bootstrap](https://github.com/twbs/bootstrap) ([MIT](https://github.com/twbs/bootstrap/blob/master/LICENSE)), [Spectre](https://github.com/picturepan2/spectre) ([MIT](https://github.com/picturepan2/spectre/blob/master/LICENSE)), [Wing](https://github.com/kbrsh/wing/) ([MIT](https://github.com/kbrsh/wing/blob/master/LICENSE)), [CSS Bed](https://github.com/ubershmekel/cssbed) & [Normalize](https://github.com/necolas/normalize.css/) ([MIT](https://github.com/necolas/normalize.css/blob/master/LICENSE.md))
- Library icons by [Feather](https://github.com/feathericons/feather) ([MIT](https://github.com/feathericons/feather/blob/master/LICENSE))
- Website icons by [Font Awesome](https://github.com/FortAwesome/Font-Awesome) ([CC BY 4.0](https://fontawesome.com/license/free))
